@@ -312,6 +312,11 @@ public class ScheduleOutboxCollection extends DAVCollection {
         return null;
     }
 
+    @Override
+    public String getSyncToken() throws WebdavProtocolException {
+        return "0";
+    }
+
     @Override
     public AbstractResource getChild(String name) throws WebdavProtocolException {
         return null;
