@@ -79,10 +79,12 @@ import com.openexchange.dav.PreconditionException;
 import com.openexchange.dav.SimilarityException;
 import com.openexchange.dav.mixins.CurrentUserPrivilegeSet;
 import com.openexchange.dav.reports.SyncStatus;
-import com.openexchange.dav.resources.CommonFolderCollection;
+import com.openexchange.dav.resources.FolderCollection;
+import com.openexchange.dav.resources.SyncToken;
 import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.groupware.contact.helpers.ContactField;
+import com.openexchange.groupware.container.CommonObject;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.search.Order;
 import com.openexchange.java.Strings;
@@ -99,6 +101,7 @@ import com.openexchange.tools.iterator.SearchIterators;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
+import com.openexchange.webdav.protocol.WebdavStatusImpl;
 import com.openexchange.webdav.protocol.helpers.AbstractResource;
 
 /**
@@ -106,12 +109,12 @@ import com.openexchange.webdav.protocol.helpers.AbstractResource;
  *
  * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
  */
-public class CardDAVCollection extends CommonFolderCollection<Contact> {
+public class CardDAVCollection extends FolderCollection<Contact> {
 
     /** A list of basic contact fields that are fetched when getting contacts from the storage */
     protected static final ContactField[] BASIC_FIELDS = {
         ContactField.OBJECT_ID, ContactField.LAST_MODIFIED, ContactField.CREATION_DATE, ContactField.UID,
-        ContactField.FILENAME, ContactField.FOLDER_ID, ContactField.VCARD_ID
+        ContactField.FILENAME, ContactField.FOLDER_ID, ContactField.VCARD_ID, ContactField.MARK_AS_DISTRIBUTIONLIST
     };
 
     protected final GroupwareCarddavFactory factory;
@@ -274,6 +277,15 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
         return isStoreOriginalVCard.booleanValue();
     }
 
+    /**
+     * Gets a value indicating whether synchronization of distribution lists is enabled or not.
+     * 
+     * @return <code>true</code> if distribution lists can be synchronized, <code>false</code>, otherwise
+     */
+    public boolean isSyncDistributionLists() {
+        return false;
+    }
+
     /**
      * Gets a list of one or more folders represented by the collection.
      *
@@ -300,9 +312,11 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
         try {
             CompositeSearchTerm searchTerm = new CompositeSearchTerm(CompositeOperation.AND);
             searchTerm.addSearchTerm(getFolderTerm(getFolders()));
-            searchTerm.addSearchTerm(getExcludeDistributionlistTerm());
+            if (false == isSyncDistributionLists()) {
+                searchTerm.addSearchTerm(getExcludeDistributionlistTerm());
+            }
             searchTerm.addSearchTerm(term);
-            searchIterator = factory.getContactService().searchContacts(factory.getSession(), term);
+            searchIterator = factory.getContactService().searchContacts(factory.getSession(), searchTerm);
             while (searchIterator.hasNext()) {
                 Contact contact = searchIterator.next();
                 if (isSynchronized(contact)) {
@@ -318,6 +332,59 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
     }
 
     @Override
+    protected WebdavPath constructPathForChildResource(Contact object) {
+        String fileName = object.getFilename();
+        if (null == fileName || 0 == fileName.length()) {
+            fileName = object.getUid();
+        }
+        String fileExtension = getFileExtension().toLowerCase();
+        if (false == fileExtension.startsWith(".")) {
+            fileExtension = "." + fileExtension;
+        }
+        return constructPathForChildResource(fileName + fileExtension);
+    }
+
+    @Override
+    protected SyncStatus<WebdavResource> getSyncStatus(SyncToken syncToken) throws OXException {
+        SyncStatus<WebdavResource> multistatus = new SyncStatus<WebdavResource>();
+        Date since = new Date(syncToken.getTimestamp());
+        boolean initialSync = 0 == since.getTime();
+        Date nextSyncToken = Tools.getLatestModified(since, this.folder);
+        /*
+         * new and modified objects
+         */
+        Collection<Contact> modifiedObjects = this.getModifiedObjects(since);
+        for (Contact object : modifiedObjects) {
+            // add resource to multistatus
+            WebdavResource resource = createResource(object, constructPathForChildResource(object));
+            int status = null != object.getCreationDate() && object.getCreationDate().after(since) ? HttpServletResponse.SC_CREATED : HttpServletResponse.SC_OK;
+            multistatus.addStatus(new WebdavStatusImpl<WebdavResource>(status, resource.getUrl(), resource));
+            // remember aggregated last modified for next sync token
+            nextSyncToken = Tools.getLatestModified(nextSyncToken, object);
+        }
+        /*
+         * deleted objects
+         */
+        Collection<Contact> deletedObjects = this.getDeletedObjects(since);
+        for (Contact object : deletedObjects) {
+            // only include objects that are not also modified (due to move operations)
+            if (null != object.getUid() && false == contains(modifiedObjects, object.getUid())) {
+                if (false == initialSync) {
+                    // add resource to multistatus
+                    WebdavResource resource = createResource(object, constructPathForChildResource(object));
+                    multistatus.addStatus(new WebdavStatusImpl<WebdavResource>(HttpServletResponse.SC_NOT_FOUND, resource.getUrl(), resource));
+                }
+                // remember aggregated last modified for parent folder
+                nextSyncToken = Tools.getLatestModified(nextSyncToken, object);
+            }
+        }
+        /*
+         * Return response with new next sync-token in response
+         */
+        multistatus.setToken(Long.toString(nextSyncToken.getTime()));
+        return multistatus;
+    }
+
     protected Collection<Contact> getModifiedObjects(Date since) throws OXException {
         List<Contact> contacts = new ArrayList<Contact>();
         for (UserizedFolder folder : getFolders()) {
@@ -332,7 +399,6 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
         return contacts;
     }
 
-    @Override
     protected Collection<Contact> getDeletedObjects(Date since) throws OXException {
         List<Contact> contacts = new ArrayList<Contact>();
         for (UserizedFolder folder : getFolders()) {
@@ -346,9 +412,13 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
         /*
          * prepare search term
          */
-        CompositeSearchTerm searchTerm = new CompositeSearchTerm(CompositeOperation.AND);
-        searchTerm.addSearchTerm(getFolderTerm(getFolders()));
-        searchTerm.addSearchTerm(getExcludeDistributionlistTerm());
+        SearchTerm<?> searchTerm = getFolderTerm(getFolders());
+        if (false == isSyncDistributionLists()) {
+            searchTerm = new CompositeSearchTerm(CompositeOperation.AND)
+                .addSearchTerm(searchTerm)
+                .addSearchTerm(getExcludeDistributionlistTerm())
+            ;
+        }
         SortOptions sortOptions = new SortOptions(ContactField.OBJECT_ID, Order.ASCENDING);
         sortOptions.setLimit(factory.getState().getContactLimit());
         /*
@@ -367,7 +437,9 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
     protected Contact getObject(String resourceName) throws OXException {
         CompositeSearchTerm searchTerm = new CompositeSearchTerm(CompositeOperation.AND);
         searchTerm.addSearchTerm(getFolderTerm(getFolders()));
-        searchTerm.addSearchTerm(getExcludeDistributionlistTerm());
+        if (false == isSyncDistributionLists()) {
+            searchTerm.addSearchTerm(getExcludeDistributionlistTerm());
+        }
         searchTerm.addSearchTerm(getResourceNameTerm(resourceName));
         SortOptions sortOptions = new SortOptions(ContactField.OBJECT_ID, Order.ASCENDING);
         sortOptions.setLimit(1);
@@ -437,6 +509,12 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
 	    }
 	}
 
+    @Override
+    public String getSyncToken() throws WebdavProtocolException {
+        Date lastModified = getLastModified();
+        return null == lastModified ? "0" : String.valueOf(lastModified.getTime());
+    }
+
     @Override
     public SyncStatus<WebdavResource> getSyncStatus(String token) throws WebdavProtocolException {
         if (null != token && 0 < token.length()) {
@@ -474,8 +552,8 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
      * @param contact The contact to check
      * @return <code>true</code> if the contact is synchronized, <code>false</code>, otherwise
      */
-    protected static boolean isSynchronized(Contact contact) {
-        if (contact.getMarkAsDistribtuionlist()) {
+    protected boolean isSynchronized(Contact contact) {
+        if (contact.getMarkAsDistribtuionlist() && false == isSyncDistributionLists()) {
             return false;
         }
         if (Strings.isEmpty(contact.getUid())) {
@@ -509,7 +587,7 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
      * @return The passed contact list reference
      * @throws OXException
      */
-    protected static List<Contact> addSynchronizedContacts(SearchIterator<Contact> searchIterator, List<Contact> contacts) throws OXException {
+    protected List<Contact> addSynchronizedContacts(SearchIterator<Contact> searchIterator, List<Contact> contacts) throws OXException {
         if (null != searchIterator) {
             while (searchIterator.hasNext()) {
                 Contact contact = searchIterator.next();
@@ -586,4 +664,13 @@ public class CardDAVCollection extends CommonFolderCollection<Contact> {
         return orTerm;
     }
 
+    private static <T extends CommonObject> boolean contains(Collection<T> objects, String uid) {
+        for (T object : objects) {
+            if (uid.equals(object.getUid())) {
+                return true;
+            }
+        }
+        return false;
+    }
+
 }
