@@ -50,11 +50,14 @@
 package com.openexchange.carddav.resources;
 
 import static com.openexchange.dav.DAVProtocol.protocolException;
+import static com.openexchange.java.Autoboxing.I;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.regex.Pattern;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.carddav.GroupwareCarddavFactory;
+import com.openexchange.dav.DAVUserAgent;
+import com.openexchange.dav.mixins.CurrentUserPrivilegeSet;
 import com.openexchange.dav.mixins.SyncToken;
 import com.openexchange.dav.resources.DAVCollection;
 import com.openexchange.dav.resources.DAVRootCollection;
@@ -78,7 +81,6 @@ public class RootCollection extends DAVRootCollection {
     private static final String EXPOSED_COLLECTIONS_PROPERTY = "com.openexchange.carddav.exposedCollections";
     private static final String REDUCED_AGGREGATED_COLLECTION_PROPERTY = "com.openexchange.carddav.reducedAggregatedCollection";
     private static final String USER_AGENT_FOR_AGGREGATED_COLLECTION_PROPERTY = "com.openexchange.carddav.userAgentForAggregatedCollection";
-    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(RootCollection.class);
     private static final String AGGREGATED_FOLDER_ID = "Contacts"; // folder ID needs to be exactly "Contacts" for backwards compatibility
     private static final String AGGREGATED_DISPLAY_NAME = "All Contacts";
 
@@ -92,10 +94,20 @@ public class RootCollection extends DAVRootCollection {
      *
      * @param factory the factory
      */
-    public RootCollection(GroupwareCarddavFactory factory) {
+    public RootCollection(GroupwareCarddavFactory factory) throws WebdavProtocolException {
     	super(factory, "Addressbooks");
     	this.factory = factory;
     	includeProperties(new SyncToken(this));
+        if (DAVUserAgent.MAC_CONTACTS.equals(getUserAgent())) {
+            /*
+             * indicate permissions from default folder also for root collection for macOS client
+             */
+            try {
+                includeProperties(new CurrentUserPrivilegeSet(factory.getState().getDefaultFolder().getOwnPermission()));
+            } catch (OXException e) {
+                throw protocolException(getUrl(), e);
+            }
+        }
     }
 
     @Override
@@ -110,7 +122,7 @@ public class RootCollection extends DAVRootCollection {
 			/*
 			 * add the aggregated collection as child resource
 			 */
-		    if (isReducedAggregatedCollection()) {
+		    if (isReducedAggregatedCollection().booleanValue()) {
 		        children.add(createReducedAggregatedCollection());
             } else {
                 children.add(createAggregatedCollection());
@@ -130,7 +142,7 @@ public class RootCollection extends DAVRootCollection {
 				throw protocolException(getUrl(), e);
 			}
 		}
-		LOG.debug("{}: got {} child resources.", getUrl(), children.size());
+		LOG.debug("{}: got {} child resources.", getUrl(), I(children.size()));
 		return children;
 	}
 
@@ -148,11 +160,7 @@ public class RootCollection extends DAVRootCollection {
 			/*
 			 * this is the aggregated collection
 			 */
-		    if (isReducedAggregatedCollection()) {
-                return createReducedAggregatedCollection();
-		    } else {
-	            return createAggregatedCollection();
-		    }
+		    return isReducedAggregatedCollection().booleanValue() ? createReducedAggregatedCollection() : createAggregatedCollection();
 		}
 		if (isUseFolderCollections()) {
 	        try {
@@ -191,7 +199,7 @@ public class RootCollection extends DAVRootCollection {
         if (null == this.reducedAggregatedCollection) {
             reducedAggregatedCollection = Boolean.TRUE;
             try {
-                reducedAggregatedCollection = Boolean.parseBoolean(factory.getConfigValue(REDUCED_AGGREGATED_COLLECTION_PROPERTY, "true"));
+                reducedAggregatedCollection = Boolean.valueOf(factory.getConfigValue(REDUCED_AGGREGATED_COLLECTION_PROPERTY, "true"));
             } catch (OXException e) {
                 LOG.error("error getting reduced aggregated collection property from config, falling back to 'true'", e);
             }
