@@ -60,6 +60,7 @@ import com.openexchange.clientinfo.ClientInfo;
 import com.openexchange.clientinfo.ClientInfoProvider;
 import com.openexchange.clientinfo.ClientInfoType;
 import com.openexchange.java.Strings;
+import com.openexchange.session.Origin;
 import com.openexchange.session.Session;
 import com.openexchange.uadetector.UserAgentParser;
 import net.sf.uadetector.ReadableUserAgent;
@@ -88,6 +89,7 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
     private static final String DAVDROID = "davdroid";
     private static final String WINDOWS_PHONE = "windows_phone";
     private static final String WINDOWS = "windows";
+    private static final String KONQUEROR = "konqueror";
     private static final String GENERIC_CALDAV = "generic_caldav";
     private static final String GENERIC_CARDDAV = "generic_carddav";
     private static final String UNKNOWN = "unknown";
@@ -105,9 +107,24 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
                 String clientFamily = getClientFamily(userAgent);
                 ReadableUserAgent readableUserAgent = userAgentParser.parse(sUserAgent);
                 if (UNKNOWN.equals(clientFamily) && (null == readableUserAgent || UNKNOWN.equalsIgnoreCase(readableUserAgent.getName()))) {
-                    // Maybe iOS accountsd?
-                    if (Strings.isNotEmpty(sUserAgent) && sUserAgent.contains("iOS") && sUserAgent.contains("accountsd")) {
-                        return new DAVClientInfo(DAVUserAgent.IOS.getReadableName(), "ios", null, IOS_DAV, null, IOS_DAV, ClientInfoType.DAV);
+                    if (Strings.isNotEmpty(sUserAgent)) {
+
+                        // Maybe iOS accountsd?
+                        if (sUserAgent.contains("iOS") && sUserAgent.contains("accountsd")) {
+                            return new DAVClientInfo(DAVUserAgent.IOS.getReadableName(), "ios", null, IOS_DAV, null, IOS_DAV, ClientInfoType.DAV);
+                        }
+
+                        // DAVx5/2.0.7-ose (2018/12/23; dav4android; okhttp/3.12.0) Android/8.1.0
+                        // Maybe DAVx5 (formerly Davdroid)
+                        if (sUserAgent.contains("DAVx5") || sUserAgent.contains("dav4android")) {
+                            return new DAVClientInfo("DAVx5", "android", null, DAVDROID, null, DAVDROID, ClientInfoType.DAV);
+                        }
+
+                        // CalDavSynchronizer/1.22
+                        // Maybe Outlook CalDAV Synchronizer
+                        if (sUserAgent.contains("CalDavSynchronizer")) {
+                            return new DAVClientInfo("Outlook CalDAV Synchronizer", WINDOWS, null, WINDOWS, null, WINDOWS, ClientInfoType.DAV);
+                        }
                     }
 
                     // Unknown User-Agent
@@ -157,6 +174,11 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
                     if (Strings.isNotEmpty(sUserAgent) && sUserAgent.contains("akonadi")) {
                         return new DAVClientInfo("KDE/Plasma DAV Client", "linux", null, "akonadi", null, "akonadi", ClientInfoType.DAV);
                     }
+
+                    // Maybe konqueror?
+                    if (Strings.isNotEmpty(sUserAgent) && sUserAgent.contains("Linux") && sUserAgent.contains("Konqueror")) {
+                        return new DAVClientInfo(KONQUEROR, "linux", null, KONQUEROR, null, KONQUEROR, ClientInfoType.DAV);
+                    }
                 }
                 return new DAVClientInfo(userAgent.getReadableName(), osFamily, osVersion, client, clientVersion, clientFamily);
             }
@@ -170,6 +192,10 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
             return null;
         }
 
+        if (!isDAV(session)) {
+            return null;
+        }
+
         String sUserAgent = (String) session.getParameter(Session.PARAM_USER_AGENT);
         if (Strings.isEmpty(sUserAgent)) {
             // Unknown User-Agent
@@ -178,7 +204,7 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
 
         try {
             DAVClientInfo davClientInfo = clientInfoCache.get(sUserAgent);
-            return UNKNOWN.equals(davClientInfo.getClientFamily()) ? null : davClientInfo;
+            return davClientInfo;
         } catch (ExecutionException e) {
             LOG.error("Failed to determine client info for User-Agent {}", sUserAgent, e.getCause());
             return new DAVClientInfo(DAVUserAgent.UNKNOWN.getReadableName(), getClientFamily(DAVUserAgent.UNKNOWN));
@@ -272,4 +298,8 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
         }
     }
 
+    private boolean isDAV(Session session) {
+        return Origin.CALDAV.equals(session.getOrigin()) || Origin.CARDDAV.equals(session.getOrigin());
+    }
+
 }
