@@ -52,6 +52,7 @@ package com.openexchange.dav;
 import java.io.IOException;
 import java.io.Writer;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import org.jdom2.Attribute;
 import org.jdom2.Element;
@@ -113,6 +114,11 @@ public class DAVProperty extends WebdavProperty {
         return element.getText();
     }
 
+    @Override
+    public List<Element> getChildren() {
+        return element.getChildren();
+    }
+
     @Override
     public Map<String, String> getAttributes() {
         HashMap<String, String> attributes = new HashMap<String, String>();
@@ -162,6 +168,11 @@ public class DAVProperty extends WebdavProperty {
         throw new UnsupportedOperationException();
     }
 
+    @Override
+    public void setChildren(List<Element> children) {
+        throw new UnsupportedOperationException();
+    }
+
     @Override
     public String toString() {
         Writer writer = null;
