@@ -129,6 +129,11 @@ public class UserPrincipalCollection extends DAVCollection {
         return new Date(0L);
     }
 
+    @Override
+    public String getSyncToken() throws WebdavProtocolException {
+        return "0";
+    }
+
     @Override
     public String getDisplayName() throws WebdavProtocolException {
         return "Users";
