@@ -107,6 +107,12 @@ public abstract class DAVRootCollection extends DAVCollection {
         return new Date(0L);
     }
 
+    @Override
+    public String getSyncToken() throws WebdavProtocolException {
+        Date lastModified = getLastModified();
+        return null == lastModified ? "0" : String.valueOf(lastModified.getTime());
+    }
+
     @Override
     public String getDisplayName() throws WebdavProtocolException {
         return displayName;
